<?xml version="1.0" encoding="UTF-8"?>
<schema xmlns="http://purl.oclc.org/dsdl/schematron" queryBinding="xslt2">
    <ns uri="urn:iso:std:iso:30042:ed-2" prefix="tbx" />
    
    <pattern id="adminTypeAttr">
        <rule context="tbx:admin">
            <assert test="@type='customerSubset' or @type='projectSubset' or @type='source'">
                admin @type must take one of the following values: 'customerSubset', 'projectSubset', 'source'
            </assert>
            <report test="@type='customerSubset' and not(parent::tbx:conceptEntry or parent::tbx:termSec)">
                customerSubset must be declared at concept or term levels.
            </report>
            <report test="@type='projectSubset' and not(parent::tbx:conceptEntry or parent::tbx:termSec)">
                projectSubset must be declared at concept or term levels.
            </report>
            <report test="@type='source' and not(parent::tbx:descripGrp[parent::tbx:termSec] or parent::tbx:termSec or parent::tbx:descripGrp[parent::tbx:conceptEntry] or parent::tbx:descripGrp[parent::tbx:langSec])">
                source must be declared 1. At the term level: (a) nested in a descripGrp (to describe the source of context), or (b) non-nested (to refer to the source of the term). 2. At the concept or lang level: nested in a descripGrp (to describe the source of a definition).
            </report>
        </rule>
    </pattern>
    
    <pattern id="descrTypeAttr">
        <rule context="tbx:descrip">
            <assert test="@type='context' or @type='definition' or @type='subjectField'">
                descrip @type must take one of the following values: 'context', 'definition', 'subjectField'
            </assert>
            <report test="(@type='subjectField') and not(parent::tbx:conceptEntry)">
                subjectField must be declared at concept level.
            </report>
            <report test="(@type='context') and not(parent::tbx:termSec or parent::tbx:descripGrp[parent::tbx:termSec])">
                context must be declared at term level, possibly nested in descripGrp with an admin element to identify a source.
            </report>
            <report test="(@type='definition') and not((parent::tbx:conceptEntry|parent::tbx:langSec) or parent::tbx:descripGrp[parent::tbx:conceptEntry|parent::tbx:langSec])">
                definition must be declared at concept or language levels levels, possibly nested in descripGrp.
            </report>
        </rule>
    </pattern>
    
    <pattern id="refTypeAttr">
        <rule context="tbx:ref">
            <assert test="@type='crossReference'">
                ref @type must take one of the following values: 'crossReference'
            </assert>
            <report test="(@type='crossReference') and not(parent::tbx:conceptEntry or parent::tbx:termSec)">
                crossReference must be declared at concept or term levels.
            </report>
        </rule>
    </pattern>
    
    <pattern id="termNoteTypeAttr">
        <rule context="tbx:termNote">
            <assert test="@type='grammaticalGender' or @type='geographicalUsage' or @type='termLocation' or @type='termType' or @type='usageStatus' or @type='administrativeStatus' or @type='partOfSpeech'">
                termNote @type must take one of the following values: 'grammaticalGender', 'geographicalUsage', 'termLocation', 'termType', 'usageStatus' (formerly: 'administrativeStatus'), 'partOfSpeech'
            </assert>
            
            <report test="@type='grammaticalGender' and (text()!='feminine' and text()!='masculine' and text()!='neuter' and text()!='epicene' and text()!='other')">
                grammaticalGender must take on of the following values: feminine, masculine, epicene, other 
            </report>
            <report test="(@type='grammaticalGender') and not(parent::tbx:termSec or parent::tbx:termNoteGrp[parent::tbx:termSec])">
                grammaticalGender must be declared at term level, possibly nested in termNoteGrp.
            </report>
            
            <report test="(@type='geographicalUsage') and not(parent::tbx:termSec or parent::tbx:termNoteGrp[parent::tbx:termSec])">
                geographicalUsage must be declared at term level, possibly nested in termNoteGrp.
            </report>
            
            <report test="(@type='termLocation') and not(parent::tbx:termSec or parent::tbx:termNoteGrp[parent::tbx:termSec])">
                termLocation must be declared at term level, possibly nested in termNoteGrp.
            </report>
            
            <report test="@type='termType' and (text()!='fullForm' and text()!='acronym' and 
                text()!='abbreviation' and text()!='shortForm' and text()!='variant' and text()!='phrase')">
                termType must take on of the following values: fullForm, acronym, abbreviation, shortForm, variant, phrase
            </report>
            <report test="(@type='termType') and not(parent::tbx:termSec or parent::tbx:termNoteGrp[parent::tbx:termSec])">
                termType must be declared at term level, possibly nested in termNoteGrp.
            </report>

            <report test="@type='administrativeStatus'" role="info">
                'usageStatus' is preferred over 'administrativeStatus'
            </report>
            <report test="@type='usageStatus' and (text()!='preferred' and text()!='admitted' and text()!='deprecated')">
                usageStatus must take on of the following values: preferred, admitted (=correct), deprecated (=avoid) 
            </report>
            <report test="(@type='usageStatus' or @type='administrativeStatus') and not(parent::tbx:termSec or parent::tbx:termNoteGrp[parent::tbx:termSec])">
                usageStatus (formerly: administrativeStatus) must be declared at term level, possibly nested in termNoteGrp.
            </report>
            
            <report test="@type='partOfSpeech' and (text()!='noun' and text()!='verb' and text()!='adjective' and text()!='adverb' and text()!='other')">
                partOfSpeech must take on of the following values: noun, verb, adjective, adverb, or other
            </report>
            <report test="(@type='partofSpeech') and not(parent::tbx:termSec or parent::tbx:termNoteGrp[parent::tbx:termSec])">
                partOfSpeech must be declared at term level, possibly nested in termNoteGrp.
            </report>
        </rule>
    </pattern>
    
    <pattern id="transacNoteTypeAttr">
        <rule context="tbx:transacNote">
            <assert test="@type='responsibility'">
                transacNote @type must take one of the following values: 'responsibility'
            </assert>
            <report test="(@type='responsibility') and not(parent::tbx:transacGrp[parent::tbx:conceptEntry or parent::tbx:langSec or parent::tbx:termSec])">
                responsibility must be declared at concept, lang, or term levels, nested inside of transacGrp.
            </report>
        </rule>
    </pattern>
    
    <pattern id="transacTypeAttr">
        <rule context="tbx:transac">
            <assert test="@type='transactionType'">
                transac @type must take one of the following values: 'transactionType'
            </assert>
            <report test="@type='transactionType' and (text()!='creation' and text()!='modification')">
                transactionType must take one of the following values: creation, modification
            </report>
            <report test="(@type='transactionType') and not(parent::tbx:transacGrp[parent::tbx:conceptEntry or parent::tbx:langSec or parent::tbx:termSec])">
                transactionType must be declared at concept, lang, or term levels, nested inside of transacGrp.
            </report>
        </rule>
    </pattern>
    
    <pattern id="xrefTypeAttr">
        <rule context="tbx:xref">
            <assert test="@type='xGraphic' or @type='externalCrossReference'">
                xref @type must take one of the following values: 'xGraphic', 'externalCrossReference'
            </assert>
            <report test="(@type='xGraphic') and not(parent::tbx:conceptEntry)">
                xGraphic must be declared at concept level.
            </report>
            <report test="(@type='externalCrossReference') and not(parent::tbx:conceptEntry or parent::tbx:termSec)">
                externalCrossReference must be declared at concept or term levels.
            </report>
        </rule>
    </pattern>
    
    
</schema>